/* 
 * $Id: ModuleService.java 2551 2009-10-21 11:22:10Z karianna $
 * $URL: https://open.jira.com/svn/IKASAN/tags/ikasan-0.8.0/console/jar/src/main/java/org/ikasan/console/module/service/ModuleService.java $
 *
 * ====================================================================
 * Ikasan Enterprise Integration Platform
 * 
 * Distributed under the Modified BSD License.
 * Copyright notice: The copyright for this software and a full listing 
 * of individual contributors are as shown in the packaged copyright.txt 
 * file. 
 * 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *
 *  - Neither the name of the ORGANIZATION nor the names of its contributors may
 *    be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 */
package org.ikasan.console.module.service;

import java.util.Set;

import org.ikasan.console.module.Module;

/**
 * Service Tier interface for providing user access to <code>Module</code>s 
 * 
 * @author Ikasan Development Team
 */
public interface ModuleService
{

    /**
     * Returns all available <code>Module</code>s or an empty Set
     * 
     * @return Set of all accessible <code>Module</code>s or an empty Set
     */
    public Set<Module> getAllModules();

    /**
     * Returns the <code>Module</code> for the given id (or returns null) 
     * 
     * @param moduleId Module id to search on 
     * @return the <code>Module</code> for the given id (or null)
     */
    public Module getModule(Long moduleId);
    
    /**
     * Returns a Set of <code>Module</code> names, given their ids
     * 
     * @param moduleIds - List of Module ids to find names for
     * @return Set of all accessible <code>Module</code> names or an empty Set
     */
    public Set<String> getModuleNames(Set<Long> moduleIds);
    
}
